==> dd_taoke_sdk-0.2.2.tar.gz: lib/model/super_search_result.dart <==
// To parse this JSON data, do
//
//     final superSearchResult = superSearchResultFromJson(jsonString);

import 'dart:convert';

import 'package:dd_taoke_sdk/model/product.dart';

SuperSearchResult superSearchResultFromJson(String str) => SuperSearchResult.fromJson(json.decode(str));

String superSearchResultToJson(SuperSearchResult data) => json.encode(data.toJson());

class SuperSearchResult {
  SuperSearchResult({
    this.totalNum,
    this.brandList,
    this.list,
    this.pageId,
  });

  int totalNum;
  List<BrandList> brandList;
  List<Product> list;
  String pageId;

  factory SuperSearchResult.fromJson(Map<String, dynamic> json) => SuperSearchResult(
    totalNum: json["totalNum"],
    brandList: List<BrandList>.from(json["brandList"].map((x) => BrandList.fromJson(x))),
    list: List<Product>.from(json["list"].map((x) => Product.fromJson(x))),
    pageId: json["pageId"],
  );

  Map<String, dynamic> toJson() => {
    "totalNum": totalNum,
    "brandList": jsonEncode(brandList),
    "list": jsonEncode(list),
    "pageId": pageId,
  };
}

class BrandList {
  BrandList({
    this.brandName,
    this.brandId,
    this.brandLogo,
  });

  String brandName;
  String brandId;
  String brandLogo;

  factory BrandList.fromJson(Map<String, dynamic> json) => BrandList(
    brandName: json["brandName"],
    brandId: json["brandId"],
    brandLogo: json["brandLogo"],
  );

  Map<String, dynamic> toJson() => {
    "brandName": brandName,
    "brandId": brandId,
    "brandLogo": brandLogo,
  };
}

==> dd_taoke_sdk-1.3.2.tar.gz: lib/model/super_search_result.dart <==
// To parse this JSON data, do
//
//     final superSearchResult = superSearchResultFromJson(jsonString);

import 'dart:convert';

import 'package:dd_taoke_sdk/model/product.dart';

SuperSearchResult superSearchResultFromJson(String str) => SuperSearchResult.fromJson(json.decode(str));

String superSearchResultToJson(SuperSearchResult data) => json.encode(data.toJson());

class SuperSearchResult {
  SuperSearchResult({
    this.totalNum,
    this.brandList,
    this.list,
    this.pageId,
  });

  int? totalNum;
  List<BrandList>? brandList;
  List<Product>? list;
  String? pageId;

  factory SuperSearchResult.fromJson(Map<String, dynamic> json) => SuperSearchResult(
    totalNum: json["totalNum"],
    brandList: List<BrandList>.from(json["brandList"].map((x) => BrandList.fromJson(x))),
    list: List<Product>.from(json["list"].map((x) => Product.fromJson(x))),
    pageId: json["pageId"],
  );

  Map<String, dynamic> toJson() => {
    "totalNum": totalNum,
    "brandList": jsonEncode(brandList),
    "list": jsonEncode(list),
    "pageId": pageId,
  };
}

class BrandList {
  BrandList({
    this.brandName,
    this.brandId,
    this.brandLogo,
  });

  String? brandName;
  String? brandId;
  String? brandLogo;

  factory BrandList.fromJson(Map<String, dynamic> json) => BrandList(
    brandName: json["brandName"],
    brandId: json["brandId"],
    brandLogo: json["brandLogo"],
  );

  Map<String, dynamic> toJson() => {
    "brandName": brandName,
    "brandId": brandId,
    "brandLogo": brandLogo,
  };
}
